@@ -19,7 +19,7 @@ our $VERSION;
 our $DEBUG;
 
 BEGIN {
-  our $VERSION = qv(5.1.5);
+  our $VERSION = qv(5.1.6);
   XSLoader::load("sealed", $VERSION);
 }
 
@@ -75,17 +75,19 @@ sub tweak ($\@\@\@$$\%) {
           or die __PACKAGE__ . ": invalid lookup: $class->$method_name - did you forget to 'use $class' first?";
         # replace $methop
         $old_pad                = B::cv_pad($cv_obj);
-        $gv                     = B::GVOP->new($gv_op->name, $gv_op->flags, $method);
+        $gv                     = B::GVOP->new($gv_op->name, $gv_op->flags, ref($gv_op) eq "B::PADOP" ? 0 : $method);
         B::cv_pad($old_pad);
         $gv->next($methop->next);
         $gv->sibparent($methop->sibparent);
         $op->next($gv);
         $$processed_op{$$_}++ for $op, $gv, $methop;
         if (ref($gv) eq "B::PADOP") {
-          # $gv->padix is useless, as well as completely missing a padname!
+          # the pad entry associated to $gv->padix is pure garbage,
+          # as well as completely missing a padname!
           # so we answer the prayer by recycling $$pads[--$idx][$targ], which
           # has the correct semantics (for $method) under assignment.
-          _padname_add($cv_obj->PADLIST, $gv->padix);
+          my $padix = $gv->padix;
+          _padname_add($cv_obj->PADLIST, $padix);
           $$pads[--$idx][$targ] = $method;
           $gv->padix($targ);
         }
@@ -127,10 +129,11 @@ sub MODIFY_CODE_ATTRIBUTES {
 	$tweaked               += eval {tweak $op, @lexical_varnames, @pads, @op_stack, $cv_obj, $pad_names, %processed_op};
         warn __PACKAGE__ . ": tweak() aborted: $@" if $@;
       }
-      if (ref($op) eq "B::PMOP") {
+
+      if ($op->isa("B::PMOP")) {
         push @op_stack, $op->pmreplroot, $op->pmreplstart, $op->next;
       }
-      elsif (grep $_ eq ref($op), "B::METHOP", "B::UNOP") {
+      elsif ($op->can("first")) {
 	for (my $kid = $op->first; ref $kid and $$kid; $kid = $kid->sibling) {
 	  push @op_stack, $kid;
 	}
@@ -143,7 +146,7 @@ sub MODIFY_CODE_ATTRIBUTES {
     }
 
     if (defined $DEBUG and $DEBUG eq "deparse" and $tweaked) {
-      eval {warn B::Deparse->new->coderef2text($rv), "\n"};
+      eval {warn "sub ", $cv_obj->GV->NAME // "__UNKNOWN__", " ", B::Deparse->new->coderef2text($rv), "\n"};
       warn "B::Deparse: coderef2text() aborted: $@" if $@;
     }
   }
